# SPDX-FileCopyrightText: 2025-present Christopher Soria <chrissoria@berkeley.edu>
#
# SPDX-License-Identifier: GPL-3.0-or-later
__version__ = "0.1.0"
__author__ = "Chris Soria"
__email__ = "chrissoria@berkeley.edu"
__title__ = "cat-cog"
__description__ = "Cognitive assessment and visual scoring powered by LLMs"
__url__ = "https://github.com/chrissoria/cat-cog"
__license__ = "GPL-3.0"
